@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
 our $DATE = '2016-06-04'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 use strict;
 use warnings;
@@ -262,7 +262,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.25 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2016-06-04.
+This document describes version 0.26 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2016-06-04.
 
 =head1 SYNOPSIS
 
@@ -281,6 +281,10 @@ This document describes version 0.25 of IPC::System::Options (from Perl distribu
  system({shell=>0}, "ls");
  system({shell=>0}, "ls -lR"); # will fail, as there is no 'ls -lR' binary
 
+ # force shell, even though there are multiple arguments (arguments will be
+ # quoted for you, including proper quoting on Win32)
+ system({shell=>1}, "ls", "-lR");
+
  # set LC_ALL/LANGUAGE/LANG environment variable
  system({lang=>"de_DE.UTF-8"}, "df");
 
@@ -314,7 +318,10 @@ argument to specify options. Currently known options:
 =item * shell => bool
 
 Can be set to 0 to always avoid invoking the shell. The default is to use the
-shell under certain conditions, like Perl's C<system()>.
+shell under certain conditions, like perl's C<system()>. But unlike perl's
+C<system()>, you can force shell usage even though you pass multiple arguments
+(in which case, the arguments will be quoted for you, including proper quoting
+on Win32).
 
 =item * lang => str
 
@@ -352,7 +359,9 @@ Capture stderr using L<Capture::Tiny>.
 =head2 backtick([ \%opts ], @args)
 
 Just like perl's backtick operator (C<qx()>) except that it accepts an optional
-hash first argument to specify options.
+hash first argument to specify options. And it can accept multiple arguments (in
+which case, the arguments will be quoted for you, including proper quoting on
+Win32).
 
 Known options:
 
